# Supporters

Development of this version of OctoPrint wouldn't have been possible without
[the financial support by the community](https://support.octoprint.org) -
thanks to everyone who contributed!

## Patrons & Sponsors

  * 3D-TECH
  * 3DPrinterOS
  * Al Mucci
  * Arnljot Arntsen
  * Ash King
  * Ben Fritsch
  * BigTreeTech
  * Boris Hussein
  * Brad Jackson
  * Christian Petropolis
  * Christian Wolf
  * Christian Würthner
  * Christoph Sigrist
  * CooperSpartan
  * Creality3D
  * DeltaMaker 3D Printers
  * Dennis Breining
  * Douglas Floyd
  * Ed Crump
  * Ernesto Martinez
  * Franziska Kunsmann
  * Hog Duske
  * Jacob Renstrom
  * James Mackay
  * Jeff Green
  * Jeff Moe
  * jeffiel
  * Jeremy Cole
  * John Cassel
  * Julian Melo
  * Justin Kaufman
  * Kaile Riser
  * Kazuhiro Ogura
  * Kenneth Jiang
  * Kurt Wubbels
  * Lachlan Bell
  * Lefteris Lertas
  * LulzBot
  * Makespace Madrid
  * Mark Greenwald
  * Mark Walker
  * Michael Aumock
  * Mike Kershaw
  * Mosaic Manufacturing
  * Norman Jaffe
  * Obico
  * Ory Weaver
  * Peopoly
  * Pete Barnwell
  * Raise3D
  * Randy C. Will
  * Ranjib Dey
  * Richard McGuire
  * Richard Michaud
  * Richard Stocks
  * Robert Gusek
  * Sean Jensen-Grey
  * Sebastien Andrivet
  * SimplyPrint
  * Stefan Krister
  * Steve Dougherty
  * Steve Thompson
  * Ulrich Kempken

and 2041 more wonderful people pledging on the [Patreon campaign](https://patreon.com/foosel) or via [GitHub Sponsors](https://github.com/users/foosel/sponsorship)!
